from __future__ import annotations

from typing import Any

from checkov.common.checks_infra.solvers.resource_solvers.exists_resource_solver import ExistsResourcerSolver
from checkov.common.graph.checks_infra.enums import Operators


class NotExistsResourcerSolver(ExistsResourcerSolver):
    operator = Operators.NOT_EXISTS  # noqa: CCE003  # a static attribute

    def get_operation(self, *args: Any, **kwargs: Any) -> bool:
        return not super().get_operation(*args, **kwargs)



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class DataLakeStoreEncryption(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that Data Lake Store accounts enables encryption"
        id = "CKV_AZURE_105"
        supported_resources = ['Microsoft.DataLakeStore/accounts',]
        categories = [CheckCategories.ENCRYPTION,]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources, missing_block_result=CheckResult.PASSED)

    def get_inspected_key(self) -> str:
        return 'properties/encryptionState'

    def get_expected_value(self) -> str:
        return "Enabled"


check = DataLakeStoreEncryption()



from __future__ import annotations

from typing import Any

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check


class SeccompPSP(BaseK8Check):
    def __init__(self) -> None:
        # CIS-1.5 5.7.2
        name = "Ensure default seccomp profile set to docker/default or runtime/default"
        id = "CKV_K8S_32"
        # Location: PodSecurityPolicy.annotations.seccomp.security.alpha.kubernetes.io/defaultProfileName
        supported_kind = ("PodSecurityPolicy",)
        categories = (CheckCategories.KUBERNETES,)
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)

    def scan_spec_conf(self, conf: dict[str, Any]) -> CheckResult:
        if "metadata" in conf:
            if "annotations" in conf["metadata"] and conf["metadata"].get("annotations"):
                for annotation in conf["metadata"]["annotations"]:
                    for key in annotation:
                        if "seccomp.security.alpha.kubernetes.io/defaultProfileName" in key:
                            if "docker/default" in annotation[key] or "runtime/default" in annotation[key]:
                                return CheckResult.PASSED
        return CheckResult.FAILED


check = SeccompPSP()



from __future__ import annotations

from abc import abstractmethod
from collections.abc import Iterable
from typing import Any, TYPE_CHECKING

from checkov.common.checks.base_check import BaseCheck
from checkov.common.models.enums import CheckCategories
from checkov.github_actions.checks.registry import registry

if TYPE_CHECKING:
    from checkov.common.models.enums import CheckResult


class BaseGithubActionsCheck(BaseCheck):
    def __init__(
        self, name: str, id: str, supported_entities: Iterable[str], block_type: str, path: str | None = None
    ) -> None:
        categories = (CheckCategories.SUPPLY_CHAIN,)

        super().__init__(
            name=name,
            id=id,
            categories=categories,
            supported_entities=supported_entities,
            block_type=block_type,
        )
        self.path = path
        registry.register(self)

    def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> tuple[CheckResult, dict[str, Any]]:
        self.entity_type = entity_type

        return self.scan_conf(conf)

    @abstractmethod
    def scan_conf(self, conf: dict[str, Any]) -> tuple[CheckResult, dict[str, Any]]:
        pass



from __future__ import annotations

from abc import abstractmethod
from typing import Any, Callable, TYPE_CHECKING

from networkx import DiGraph

import concurrent.futures

from concurrent.futures import ThreadPoolExecutor

from checkov.common.graph.checks_infra.enums import SolverType
from checkov.common.graph.checks_infra.solvers.base_solver import BaseSolver
from checkov.common.graph.graph_builder import CustomAttributes

if TYPE_CHECKING:
    from checkov.common.typing import LibraryGraph


class BaseResourceSolver(BaseSolver):
    def __init__(self, resource_types: list[str]) -> None:
        super().__init__(SolverType.RESOURCE)
        self.resource_types = resource_types
        self.vertices: list[dict[str, Any]] = []

    @abstractmethod
    def get_operation(self, resource_type: str) -> bool:
        raise NotImplementedError()

    def _get_operation(self, *args: Any, **kwargs: Any) -> Callable[..., bool]:
        # not needed
        return lambda: True

    def run(
        self, graph_connector: LibraryGraph
    ) -> tuple[list[dict[str, Any]], list[dict[str, Any]], list[dict[str, Any]]]:
        executer = ThreadPoolExecutor()
        jobs = []
        passed_vertices: list[dict[str, Any]] = []
        failed_vertices: list[dict[str, Any]] = []
        unknown_vertices: list[dict[str, Any]] = []

        if isinstance(graph_connector, DiGraph):
            for _, data in graph_connector.nodes(data=True):
                jobs.append(executer.submit(self._process_node, data, passed_vertices, failed_vertices, unknown_vertices))

            concurrent.futures.wait(jobs)
            return passed_vertices, failed_vertices, unknown_vertices

        for _, data in graph_connector.nodes():
            result = self.get_operation(resource_type=data.get(CustomAttributes.RESOURCE_TYPE))
            if result:
                passed_vertices.append(data)
            else:
                failed_vertices.append(data)

        return passed_vertices, failed_vertices, []

    def _process_node(self, data: dict[str, str], passed_vartices: list[dict[str, Any]],
                      failed_vertices: list[dict[str, Any]], unknown_vertices: list[dict[str, Any]]) -> None:
        result = self.get_operation(data.get(CustomAttributes.RESOURCE_TYPE))  # type:ignore[arg-type]
        # A None indicate for UNKNOWN result - the vertex shouldn't be added to the passed or the failed vertices
        if result is None:
            unknown_vertices.append(data)
        elif result:
            passed_vartices.append(data)
        else:
            failed_vertices.append(data)



from typing import Any, Dict, List

from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class DBInstanceLogging(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that respective logs of Amazon Relational Database Service (Amazon RDS) are enabled"
        id = "CKV_AWS_129"
        supported_resources = ["aws_db_instance"]
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "enabled_cloudwatch_logs_exports/[0]"

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        logs_exports = conf.get('enabled_cloudwatch_logs_exports', [[]])
        if not logs_exports:
            return CheckResult.FAILED
        return CheckResult.PASSED if logs_exports[0] else CheckResult.FAILED

    def get_expected_value(self) -> Any:
        return ANY_VALUE


check = DBInstanceLogging()



from typing import Any

from checkov.common.models.enums import CheckCategories
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class PostgressSQLGeoBackupEnabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that PostgreSQL server enables geo-redundant backups"
        id = "CKV_AZURE_102"
        supported_resources = ['Microsoft.DBforPostgreSQL/servers']
        categories = [CheckCategories.BACKUP_AND_RECOVERY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> Any:
        return 'properties/storageProfile/geoRedundantBackup'

    def get_expected_value(self) -> str:
        return 'Enabled'


check = PostgressSQLGeoBackupEnabled()



from __future__ import annotations
from checkov.common.models.enums import CheckCategories
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class ACREnableImageQuarantine(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure container image quarantine, scan, and mark images verified"
        id = "CKV_AZURE_166"
        supported_resources = ("Microsoft.ContainerRegistry/registries",)
        categories = (CheckCategories.SUPPLY_CHAIN,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "properties/policies/quarantinePolicy/status"

    def get_expected_value(self) -> str:
        return "enabled"


check = ACREnableImageQuarantine()



from typing import Dict, List, Any
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.arm.base_resource_check import BaseResourceCheck


class AzureSynapseWorkspacesHaveNoIPFirewallRulesAttached(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure that Azure Synapse workspaces have no IP firewall rules attached"
        id = "CKV2_AZURE_19"
        supported_resources = ["Microsoft.Synapse/workspaces"]
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        depends_on = conf.get("dependsOn")
        if depends_on is None or not len(depends_on):
            return CheckResult.PASSED
        if any('Microsoft.Synapse/workspaces/firewallRules' in item for item in depends_on):
            return CheckResult.FAILED
        return CheckResult.PASSED


check = AzureSynapseWorkspacesHaveNoIPFirewallRulesAttached()



from checkov.common.models.enums import CheckCategories
from checkov.kubernetes.checks.resource.base_spec_omitted_or_value_check import BaseSpecOmittedOrValueCheck


class PrivilegedContainersPSP(BaseSpecOmittedOrValueCheck):
    def __init__(self) -> None:
        # CIS-1.3 1.7.1
        # CIS-1.5 5.2.1
        name = "Do not admit privileged containers"
        id = "CKV_K8S_2"
        # Location: PodSecurityPolicy.spec.privileged
        supported_kind = ("PodSecurityPolicy",)
        categories = (CheckCategories.KUBERNETES,)
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)

    def get_inspected_key(self) -> str:
        return "spec/privileged"


check = PrivilegedContainersPSP()



from __future__ import annotations


from checkov.common.graph.checks_infra.enums import Operators
from checkov.common.checks_infra.solvers.resource_solvers.base_resource_solver import BaseResourceSolver


class ExistsResourcerSolver(BaseResourceSolver):
    operator = Operators.EXISTS  # noqa: CCE003  # a static attribute

    def get_operation(self, resource_type: str | None) -> bool:
        return resource_type in self.resource_types
